# 0.2.0 (Fri Dec 24 2021)

#### 🚀 Enhancement

- Update README.md and move transforms [#187](https://github.com/neuronets/nobrainer/pull/187) ([@Hoda1394](https://github.com/Hoda1394) [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]) [@satra](https://github.com/satra))

#### 🐛 Bug Fix

- Documentation update [#184](https://github.com/neuronets/nobrainer/pull/184) ([@Aakanksha-Rana](https://github.com/Aakanksha-Rana) [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]) [@satra](https://github.com/satra))
- Correction of G_dice and multi_class dice_calculation [#164](https://github.com/neuronets/nobrainer/pull/164) ([@kaczmarj](https://github.com/kaczmarj) [@Aakanksha-Rana](https://github.com/Aakanksha-Rana) [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]) [@satra](https://github.com/satra))
- DOC: Update link to CITATION file [#190](https://github.com/neuronets/nobrainer/pull/190) ([@arokem](https://github.com/arokem))
- Bayesian: 3D bayes_by_backprop_layer + Distributed Weight Consolidation [#185](https://github.com/neuronets/nobrainer/pull/185) ([@Aakanksha-Rana](https://github.com/Aakanksha-Rana) [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]) [@satra](https://github.com/satra))
- [pre-commit.ci] pre-commit autoupdate [#188](https://github.com/neuronets/nobrainer/pull/188) ([@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))
- Fix tf & tfp compatibility with python version [#186](https://github.com/neuronets/nobrainer/pull/186) ([@Hoda1394](https://github.com/Hoda1394) [@satra](https://github.com/satra))
- [pre-commit.ci] pre-commit autoupdate [#183](https://github.com/neuronets/nobrainer/pull/183) ([@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))
- Added Clipping constraint and KLD loss with CD [#180](https://github.com/neuronets/nobrainer/pull/180) ([@Aakanksha-Rana](https://github.com/Aakanksha-Rana) [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]) [@satra](https://github.com/satra))
- ENH: Allow multichannel input [#177](https://github.com/neuronets/nobrainer/pull/177) ([@richford](https://github.com/richford) [@satra](https://github.com/satra))
- Add citation [#181](https://github.com/neuronets/nobrainer/pull/181) ([@Aakanksha-Rana](https://github.com/Aakanksha-Rana) [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]) [@satra](https://github.com/satra))
- [pre-commit.ci] pre-commit autoupdate [#182](https://github.com/neuronets/nobrainer/pull/182) ([@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))
- adding brain siamese network models and test cases [#172](https://github.com/neuronets/nobrainer/pull/172) ([@dhritimandas](https://github.com/dhritimandas) [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]) [@satra](https://github.com/satra))
- Added dcgan architecture with tests [#66](https://github.com/neuronets/nobrainer/pull/66) ([@wazeerzulfikar](https://github.com/wazeerzulfikar) [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]) [@satra](https://github.com/satra))
- BF: Add block_length param to dataset.interleave [#175](https://github.com/neuronets/nobrainer/pull/175) ([@richford](https://github.com/richford) [@satra](https://github.com/satra))
- Weightnorm feature for Variational layer [#166](https://github.com/neuronets/nobrainer/pull/166) ([@Aakanksha-Rana](https://github.com/Aakanksha-Rana) [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]) [@satra](https://github.com/satra))
- [pre-commit.ci] pre-commit autoupdate [#179](https://github.com/neuronets/nobrainer/pull/179) ([@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))
- [pre-commit.ci] pre-commit autoupdate [#178](https://github.com/neuronets/nobrainer/pull/178) ([@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))
- [pre-commit.ci] pre-commit autoupdate [#173](https://github.com/neuronets/nobrainer/pull/173) ([@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))
- [pre-commit.ci] pre-commit autoupdate [#170](https://github.com/neuronets/nobrainer/pull/170) ([@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))
- [pre-commit.ci] pre-commit autoupdate [#165](https://github.com/neuronets/nobrainer/pull/165) ([@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))
- [pre-commit.ci] pre-commit autoupdate [#163](https://github.com/neuronets/nobrainer/pull/163) ([@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))
- fix: readme to remove qualified install [#162](https://github.com/neuronets/nobrainer/pull/162) ([@satra](https://github.com/satra) [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))
- fix: remove unnecessary step in release action [#158](https://github.com/neuronets/nobrainer/pull/158) ([@satra](https://github.com/satra))

#### ⚠️ Pushed to `master`

- Update .zenodo.json ([@satra](https://github.com/satra))

#### Authors: 9

- [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot])
- Aakanksha Rana ([@Aakanksha-Rana](https://github.com/Aakanksha-Rana))
- Adam Richie-Halford ([@richford](https://github.com/richford))
- Ariel Rokem ([@arokem](https://github.com/arokem))
- Dhritiman Das ([@dhritimandas](https://github.com/dhritimandas))
- Hoda Rajaei ([@Hoda1394](https://github.com/Hoda1394))
- Jakub Kaczmarzyk ([@kaczmarj](https://github.com/kaczmarj))
- Satrajit Ghosh ([@satra](https://github.com/satra))
- Wazeer Zulfikar ([@wazeerzulfikar](https://github.com/wazeerzulfikar))

---

# 0.1.1 (Tue Jun 22 2021)

#### 🐛 Bug Fix

- fix: replace key retrieval and normalizers [#157](https://github.com/neuronets/nobrainer/pull/157) ([@satra](https://github.com/satra))
- fix: separate auto release and publish to pypi [#156](https://github.com/neuronets/nobrainer/pull/156) ([@satra](https://github.com/satra))
- [pre-commit.ci] pre-commit autoupdate [#154](https://github.com/neuronets/nobrainer/pull/154) ([@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))

#### ⚠️ Pushed to `master`

- fix: add twine upload to release ([@satra](https://github.com/satra))

#### Authors: 2

- [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot])
- Satrajit Ghosh ([@satra](https://github.com/satra))

---

# 0.1.0 (Sat Jun 19 2021)

#### 🚀 Enhancement

- fix: change nobrainer models repo, readme, and guide notebooks [#150](https://github.com/neuronets/nobrainer/pull/150) ([@satra](https://github.com/satra) [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))
- Enh/docker [#148](https://github.com/neuronets/nobrainer/pull/148) ([@satra](https://github.com/satra))
- fix: Update release.yml to handle branch protection [#147](https://github.com/neuronets/nobrainer/pull/147) ([@satra](https://github.com/satra))

#### 🐛 Bug Fix

- add zenodo file [#153](https://github.com/neuronets/nobrainer/pull/153) ([@satra](https://github.com/satra) [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))
- enh: change standardize in dataset creation to a callable [#152](https://github.com/neuronets/nobrainer/pull/152) ([@satra](https://github.com/satra))
- ENH: Bayesian neural network architectures with training requisites [#126](https://github.com/neuronets/nobrainer/pull/126) ([@Aakanksha-Rana](https://github.com/Aakanksha-Rana) [@satra](https://github.com/satra) [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))
- fix: standardize not imported for dataset creation [#151](https://github.com/neuronets/nobrainer/pull/151) ([@satra](https://github.com/satra))
- add estimator prediction function for kwyk model [#149](https://github.com/neuronets/nobrainer/pull/149) ([@Hoda1394](https://github.com/Hoda1394) [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]) [@satra](https://github.com/satra))
- Fix for the generate cli pytest and generation guide notebook [#146](https://github.com/neuronets/nobrainer/pull/146) ([@wazeerzulfikar](https://github.com/wazeerzulfikar))
- Created using Colaboratory [#144](https://github.com/neuronets/nobrainer/pull/144) ([@satra](https://github.com/satra) [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))
- [pre-commit.ci] pre-commit autoupdate [#142](https://github.com/neuronets/nobrainer/pull/142) ([@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))
- FIX: keeping compatibility with official tensorflow docker images [#141](https://github.com/neuronets/nobrainer/pull/141) ([@satra](https://github.com/satra))
- Add bayesian prediction [#128](https://github.com/neuronets/nobrainer/pull/128) ([@Hoda1394](https://github.com/Hoda1394) [@satra](https://github.com/satra) [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))
- ENH: Transform composition [#113](https://github.com/neuronets/nobrainer/pull/113) ([@Aakanksha-Rana](https://github.com/Aakanksha-Rana) [@satra](https://github.com/satra) [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))
- fixes https://github.com/neuronets/nobrainer/issues/124 [#125](https://github.com/neuronets/nobrainer/pull/125) ([@shashankbansal6](https://github.com/shashankbansal6) [@satra](https://github.com/satra))
- fix: update dockerfiles to tensorflow 2.5.0 [#140](https://github.com/neuronets/nobrainer/pull/140) ([@satra](https://github.com/satra))
- ENH: Add progressive gan to nobrainer [#138](https://github.com/neuronets/nobrainer/pull/138) ([@wazeerzulfikar](https://github.com/wazeerzulfikar) [@satra](https://github.com/satra) [@djarecka](https://github.com/djarecka))
- add: release mechanism [#139](https://github.com/neuronets/nobrainer/pull/139) ([@satra](https://github.com/satra))
- Add progressiveGAN for 3D brain MR images [#114](https://github.com/neuronets/nobrainer/pull/114) ([@wazeerzulfikar](https://github.com/wazeerzulfikar))
- Enh/notebooks [#137](https://github.com/neuronets/nobrainer/pull/137) ([@satra](https://github.com/satra))
- add CI workflow badge [#133](https://github.com/neuronets/nobrainer/pull/133) ([@kaczmarj](https://github.com/kaczmarj))
- move CI to github actions [#131](https://github.com/neuronets/nobrainer/pull/131) ([@Hoda1394](https://github.com/Hoda1394))
- Enh/minor updates [#123](https://github.com/neuronets/nobrainer/pull/123) ([@kaczmarj](https://github.com/kaczmarj))
- export `LC_ALL` and `LANG` + use tensorflow 2.3.1 [#118](https://github.com/neuronets/nobrainer/pull/118) ([@kaczmarj](https://github.com/kaczmarj))
- use specific version of cloudpickle to fix import error [#108](https://github.com/neuronets/nobrainer/pull/108) ([@kaczmarj](https://github.com/kaczmarj))
- force reinstall of python dependencies in travis ci [#102](https://github.com/neuronets/nobrainer/pull/102) ([@kaczmarj](https://github.com/kaczmarj))

#### ⚠️ Pushed to `master`

- fix: use token for auto with repo access ([@satra](https://github.com/satra))
- Created using Colaboratory ([@satra](https://github.com/satra))
- Update release.yml ([@satra](https://github.com/satra))

#### Authors: 8

- [@Hoda1394](https://github.com/Hoda1394)
- [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot])
- Aakanksha Rana ([@Aakanksha-Rana](https://github.com/Aakanksha-Rana))
- Dorota Jarecka ([@djarecka](https://github.com/djarecka))
- Jakub Kaczmarzyk ([@kaczmarj](https://github.com/kaczmarj))
- Satrajit Ghosh ([@satra](https://github.com/satra))
- Shashank Bansal ([@shashankbansal6](https://github.com/shashankbansal6))
- Wazeer Zulfikar ([@wazeerzulfikar](https://github.com/wazeerzulfikar))
